Summary command for use on an object of class "markophylo". The estimated substitution rates for each partition specified along with the estimated \(\alpha\)(s) for the gamma distribution (if any) and prior probability of discrete characters at the root (if estimated) are printed. If branch groupings (or clades) were specified, then the rates (and corresponding standard errors) are displayed in a matrix with the columns representing the different branch groupings (ordered by the subsets of x$bg where x is an object of class "idea"). The rows represent the indices of the model matrix.
# S3 method for markophylo
print(x, ...)Printing function
An object of class "markophylo".
Ignore this
Utkarsh J. Dang and G. Brian Golding
See also estimaterates.